/*
    qZenAstroChoose : Software to easily choose fits pictures in astroPhotography
    Copyright (C) 2017 Olivier Poitevin

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    Contact : code@zener.fr

*/

#include "dialogpreferences.h"
#include "ui_dialogpreferences.h"
#include <qfiledialog.h>

DialogPreferences::DialogPreferences(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DialogPreferences)
{
    languagesList<<"en";
    languagesList<<"fr";

    ui->setupUi(this);
    result=false;
}

DialogPreferences::~DialogPreferences()
{
    delete ui;
}

bool DialogPreferences::getResult()
{
    return result;
}

void DialogPreferences::setMainDir(QString S)
{
    ui->lineEditMainDir->setText(S);
}

void DialogPreferences::setImageDir(QString S)
{
    ui->lineEditImageDir->setText(S);
}

void DialogPreferences::setFilter(QString S)
{
    ui->lineEditFilter->setText(S);
}

void DialogPreferences::setLanguage(QString S)
{
    int i=languagesList.indexOf(S);
    ui->comboBoxLanguages->setCurrentIndex(i);
}



QString DialogPreferences::getMainDir()
{
    return ui->lineEditMainDir->text();
}

QString DialogPreferences::getImageDir()
{
    return ui->lineEditImageDir->text();
}

QString DialogPreferences::getFilter()
{
    return ui->lineEditFilter->text();
}

QString DialogPreferences::getLanguage()
{
    return languagesList.at(ui->comboBoxLanguages->currentIndex());
}


void DialogPreferences::on_pushButtonCancel_clicked()
{
    result=false;
    this->hide();
}

void DialogPreferences::on_pushButtonOK_clicked()
{
    result=true;
    this->hide();
}

void DialogPreferences::on_pushButtonMainDirChoose_clicked()
{
    QString dir = QFileDialog::getExistingDirectory(this, tr("Open Main Directory"),
                                                 getMainDir(),
                                                 QFileDialog::ShowDirsOnly
                                                 | QFileDialog::DontResolveSymlinks);
    setMainDir(dir);
}
