/*
    qZenAstroChoose : Software to easily choose fits pictures in astroPhotography
    Copyright (C) 2017 Olivier Poitevin

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    Contact : code@zener.fr

*/

#ifndef FITSIMAGE_H
#define FITSIMAGE_H

#include <QObject>
#include <QByteArray>
#include <QImage>


#define FITSHDUSIZE		2880
#define FITSKEYWORDSIZE	80
#define FITSKEYDATOFST	0x1E

#define HDUEQUALPOS	8

// fits keywords
#define FITKW_SIMPLE	"SIMPLE"
#define FITKW_BITPIX	"BITPIX"
#define FITKW_NAXISG	"NAXIS"
#define FITKW_NAXIS1	"NAXIS1"
#define FITKW_NAXIS2	"NAXIS2"
#define FITKW_MIPSHI	"MIPS-HI"
#define FITKW_MIPSLO	"MIPS-LO"
#define FITKW_MIPSX1	"MIPS-X1"
#define FITKW_MIPSY1	"MIPS-Y1"
#define FITKW_MIPSX2	"MIPS-X2"
#define FITKW_MIPSY2	"MIPS-Y2"
#define FITKW_MIPSBIX	"MIPS-BIX"
#define FITKW_MIPSBIY	"MIPS-BIY"
#define FITKW_MIPSCCD	"MIPS-CCD"
#define FITKW_MIPSFL	"MIPS-FL"
#define FITKW_MIPSSX	"MIPS-SX"
#define FITKW_MIPSSY	"MIPS-SY"
#define FITKW_MIPSNOR	"MIPS-NOR"
#define FITKW_MIPSCST	"MIPS-CST"
#define FITKW_DATEOBS	"DATE-OBS"
#define FITKW_UTSTART	"UT-START"
#define FITKW_EXPTIME	"EXPTIME"
#define FITKW_END		"END"

typedef struct{
    char keyword[FITSHDUSIZE/FITSKEYWORDSIZE][FITSKEYWORDSIZE];
}Fits_Hdu_st;


class FitsImage : public QObject
{
    Q_OBJECT
public:
    FitsImage(QObject *parent = 0);
    ~FitsImage();

    bool loadImage(QString &filename);

    QImage getImage();
    float getExpoTime();

    QString getImageDate();
    QString getImageTime();

    QString getLastErrMsg();

    int getImageWidth();
    int getImageHeight();

private:
    bool parseHdu(Fits_Hdu_st *hdu);
    void convertCfaToQimg(QByteArray &src);

    // geometry :
    int width;
    int height;

    // time
    float expoTime;

    // color :
    int minimumCol;
    int maximumCol;


    QString DateObs;
    QString TimeObs;

    // image to display
    QImage display;

    QString lastErrMsg;

    unsigned char colCurveLut[65536];

};

#endif // FITSIMAGE_H
